from cli.tester.dataset_template import generatedClass
from cli.tester.reporter_template import generatedClass
from cli.tester.tester_template import generatedClass
from cli.tester.server_run_template import generatedClass
from cli.tester.pool_template import generatedClass

